@@ -1,6 +1,10 @@
 """LMU provides a package for deep learning with Legendre Memory Units."""
 
-from .lmu import Legendre, InputScaled, LMUCell, LMUCellODE, LMUCellGating
+from .layers import (
+    LMUCell,
+    LMUFFT,
+    LMU,
+)
 
 from .version import version as __version__
 
